package com.bonus.material.ma.service.impl;

import java.util.List;
import com.bonus.common.core.utils.DateUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.bonus.material.ma.mapper.PropSetMapper;
import com.bonus.material.ma.domain.PropSet;
import com.bonus.material.ma.service.IPropSetService;

/**
 * 资产属性配置Service业务层处理
 * 
 * @author xsheng
 * @date 2024-09-27
 */
@Service
public class PropSetServiceImpl implements IPropSetService 
{
    @Autowired
    private PropSetMapper propSetMapper;

    /**
     * 查询资产属性配置
     * 
     * @param id 资产属性配置主键
     * @return 资产属性配置
     */
    @Override
    public PropSet selectPropSetById(Long id)
    {
        return propSetMapper.selectPropSetById(id);
    }

    /**
     * 查询资产属性配置列表
     * 
     * @param propSet 资产属性配置
     * @return 资产属性配置
     */
    @Override
    public List<PropSet> selectPropSetList(PropSet propSet)
    {
        return propSetMapper.selectPropSetList(propSet);
    }

    /**
     * 新增资产属性配置
     * 
     * @param propSet 资产属性配置
     * @return 结果
     */
    @Override
    public int insertPropSet(PropSet propSet)
    {
        propSet.setCreateTime(DateUtils.getNowDate());
        return propSetMapper.insertPropSet(propSet);
    }

    /**
     * 修改资产属性配置
     * 
     * @param propSet 资产属性配置
     * @return 结果
     */
    @Override
    public int updatePropSet(PropSet propSet)
    {
        propSet.setUpdateTime(DateUtils.getNowDate());
        return propSetMapper.updatePropSet(propSet);
    }

    /**
     * 批量删除资产属性配置
     * 
     * @param ids 需要删除的资产属性配置主键
     * @return 结果
     */
    @Override
    public int deletePropSetByIds(Long[] ids)
    {
        return propSetMapper.deletePropSetByIds(ids);
    }

    /**
     * 删除资产属性配置信息
     * 
     * @param id 资产属性配置主键
     * @return 结果
     */
    @Override
    public int deletePropSetById(Long id)
    {
        return propSetMapper.deletePropSetById(id);
    }
}
