package com.bonus.material.ma.controller;

import java.util.List;
import javax.servlet.http.HttpServletResponse;
import com.bonus.common.log.enums.OperaType;
import com.bonus.material.common.annotation.PreventRepeatSubmit;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.bonus.common.log.annotation.SysLog;
import com.bonus.common.security.annotation.RequiresPermissions;
import com.bonus.material.ma.domain.PropSet;
import com.bonus.material.ma.service.IPropSetService;
import com.bonus.common.core.web.controller.BaseController;
import com.bonus.common.core.web.domain.AjaxResult;
import com.bonus.common.core.utils.poi.ExcelUtil;
import com.bonus.common.core.web.page.TableDataInfo;

/**
 * 资产属性配置Controller
 * 
 * @author xsheng
 * @date 2024-09-27
 */
@Api(tags = "资产属性配置接口")
@RestController
@RequestMapping("/ma_prop_set")
public class PropSetController extends BaseController
{
    @Autowired
    private IPropSetService propSetService;

    /**
     * 查询资产属性配置列表
     */
    @ApiOperation(value = "查询资产属性配置列表")
    @RequiresPermissions("ma:set:list")
    @GetMapping("/list")
    public TableDataInfo list(PropSet propSet)
    {
        startPage();
        List<PropSet> list = propSetService.selectPropSetList(propSet);
        return getDataTable(list);
    }

    /**
     * 导出资产属性配置列表
     */
    @ApiOperation(value = "导出资产属性配置列表")
    @PreventRepeatSubmit
    @RequiresPermissions("ma:set:export")
    @SysLog(title = "资产属性配置", businessType = OperaType.EXPORT, logType = 1,module = "仓储管理->导出资产属性配置")
    @PostMapping("/export")
    public void export(HttpServletResponse response, PropSet propSet)
    {
        List<PropSet> list = propSetService.selectPropSetList(propSet);
        ExcelUtil<PropSet> util = new ExcelUtil<PropSet>(PropSet.class);
        util.exportExcel(response, list, "资产属性配置数据");
    }

    /**
     * 获取资产属性配置详细信息
     */
    @ApiOperation(value = "获取资产属性配置详细信息")
    @RequiresPermissions("ma:set:query")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return success(propSetService.selectPropSetById(id));
    }

    /**
     * 新增资产属性配置
     */
    @ApiOperation(value = "新增资产属性配置")
    @PreventRepeatSubmit
    @RequiresPermissions("ma:set:add")
    @SysLog(title = "资产属性配置", businessType = OperaType.INSERT, logType = 1,module = "仓储管理->新增资产属性配置")
    @PostMapping
    public AjaxResult add(@RequestBody PropSet propSet)
    {
        return toAjax(propSetService.insertPropSet(propSet));
    }

    /**
     * 修改资产属性配置
     */
    @ApiOperation(value = "修改资产属性配置")
    @PreventRepeatSubmit
    @RequiresPermissions("ma:set:edit")
    @SysLog(title = "资产属性配置", businessType = OperaType.UPDATE, logType = 1,module = "仓储管理->修改资产属性配置")
    @PutMapping
    public AjaxResult edit(@RequestBody PropSet propSet)
    {
        return toAjax(propSetService.updatePropSet(propSet));
    }

    /**
     * 删除资产属性配置
     */
    @ApiOperation(value = "删除资产属性配置")
    @PreventRepeatSubmit
    @RequiresPermissions("ma:set:remove")
    @SysLog(title = "资产属性配置", businessType = OperaType.DELETE, logType = 1,module = "仓储管理->删除资产属性配置")
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids)
    {
        return toAjax(propSetService.deletePropSetByIds(ids));
    }
}
